When the association among three categorical variables is asymmetric such that one variable is a
logical response variable to the other variables, we recommend calculating the non-symmetrical
three-way measure of predictability such as the Marcotorchino index (Marcotorchino, 1985).
The function tau3 partitions the Marcotorchino statistic when, in CA3variants,
we set the parameter ca3type = "NSCA3".